# CareHQ Python API client

CareHQ API Client for Python.


## Installation

```
pip install carehq
```


## Requirements

- Python 3.7+


# Usage

```Python

import carehq

api_client = carehq.APIClient(
    account_id='MY_ACCOUNT_ID',
    api_key='MY_API_KEY',
    api_secret='MY_API_SECRET'
)

users = api_client(
    'get',
    'users',
    {'filters-q': ['lyra']}
)

```
